def sum_as_string(a: int, b: int) -> str: ...

class NewInt:
    def __init__(self, number: int) -> None: ...
    def add(self, second_number: int) -> int: ...
    def mul(self, second_number: int) -> int: ...
    def loop_add_mul_seq(self, number_of_loops: int, add_number: int, mul_number: int) -> int: ...
    def get_number(self) -> int: ...

class NewFloat:
    def __init__(self, number: float) -> None: ...
    def add(self, second_number: float) -> float: ...
    def mul(self, second_number: float) -> float: ...
    def loop_add_mul_seq(self, number_of_loops: int, add_number: float, mul_number: float) -> float: ...
    def get_number(self) -> float: ...
